@@ -23,8 +23,6 @@
 #include <bonobo/bonobo-ui-preferences.h>
 #include <bonobo/bonobo-ui-private.h>
 
-#include <bonobo/bonobo-ui-toolbar-separator-item.h>
-
 static GObjectClass *parent_class = NULL;
 
 #define PARENT_TYPE bonobo_ui_sync_get_type ()
@@ -122,7 +120,7 @@ impl_bonobo_ui_sync_status_state (BonoboUISync     *sync,
 			    !atoi (hidden))
 				has_grip = FALSE;
 		}
-		if (has_item_to_the_right (parent, widget))
+		if (has_item_to_the_right (GTK_BOX (parent), widget))
 			has_grip = FALSE;
 
 		gtk_statusbar_set_has_resize_grip (msync->main_status, has_grip);
@@ -221,6 +219,10 @@ impl_bonobo_ui_sync_status_build (BonoboUISync     *sync,
 		char *behavior;
 		char **behavior_array;
 
+		gboolean pack_start = FALSE;
+		gboolean fill = FALSE;
+		gboolean expand = FALSE;
+
 		widget = bonobo_ui_engine_build_control (sync->engine, node);
 		if (widget) {
 			behavior_array = NULL;
@@ -229,13 +231,18 @@ impl_bonobo_ui_sync_status_build (BonoboUISync     *sync,
 				bonobo_ui_node_free_string (behavior);
 			}
 
-			if (behavior_array != NULL && 
-			    string_array_contains (behavior_array, "pack-start"))
+			if (behavior_array != NULL) {
+				pack_start = string_array_contains (behavior_array, "pack-start");
+				fill = string_array_contains (behavior_array, "fill");
+				expand = string_array_contains (behavior_array, "expand");
+			}
+			
+			if (pack_start)
 				gtk_box_pack_start (GTK_BOX (parent), widget,
-						    FALSE, FALSE, 0);
+						    expand, fill, 0);
 			else
 				gtk_box_pack_end (GTK_BOX (parent), widget,
-						  FALSE, FALSE, 0);
+						  expand, fill, 0);
 
 			g_strfreev (behavior_array);
 		}
@@ -257,9 +264,7 @@ impl_bonobo_ui_sync_status_build_placeholder (BonoboUISync     *sync,
 	GtkWidget *widget;
 	BonoboUISyncStatus *msync = BONOBO_UI_SYNC_STATUS (sync);
 
-	g_warning ("TESTME: status bar placeholders");
-
-	widget = bonobo_ui_toolbar_separator_item_new ();
+	widget = gtk_vseparator_new ();
 	gtk_widget_set_sensitive (widget, FALSE);
 
 	gtk_box_pack_end (GTK_BOX (parent), widget,
