@@ -19,7 +19,7 @@
 
 #include <bonobo/bonobo-ui-xml.h>
 #include <bonobo/bonobo-ui-util.h>
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n-lib.h>
 #include <bonobo/bonobo-ui-private.h>
 
 static gchar *find_pixmap_in_path (const gchar *filename);
@@ -45,7 +45,7 @@ static const gint8 read_lut[128] = {
 	 -1, 10, 11, 12, 13, 14, 15, -1,		/* 0x60 -> 0x67 */
 	 -1, -1, -1, -1, -1, -1, -1, -1,
 	 -1, -1, -1, -1, -1, -1, -1, -1,		/* 0x70 -> 0x77 */
-	 -1, -1, -1, -1, -1, -1, -1, -1,
+	 -1, -1, -1, -1, -1, -1, -1, -1
 };
 
 static inline void
@@ -91,7 +91,7 @@ read_byte (const char *start)
 	return (nibble1 << 4) + nibble2;
 }
 
-static inline const guint32
+static inline guint32
 read_four_bytes (const char *pos)
 {
 	return ((read_byte (pos) << 24) |
@@ -228,7 +228,7 @@ find_pixmap_in_path (const gchar *filename)
 {
 	gchar *file;
 
-	if (filename [0] == '/')
+	if (g_path_is_absolute (filename))
 		return g_strdup (filename);
 
 	file = gnome_program_locate_file (gnome_program_get (),
@@ -358,6 +358,13 @@ bonobo_ui_util_xml_set_image (GtkImage     *image,
 	} else
 		return;
 
+	if (!text) {
+		if (g_getenv ("BONOBO_DEBUG"))
+			g_warning ("Missing pixname on '%s'",
+				    bonobo_ui_xml_make_path (node));
+		return;
+	}
+
 	if (!strcmp (type, "stock")) {
 		if (gtk_icon_factory_lookup_default (text))
 			bonobo_ui_image_set_stock (image, text, icon_size);
@@ -371,7 +378,7 @@ bonobo_ui_util_xml_set_image (GtkImage     *image,
 		return;
 	}
 
-	key = g_strdup_printf ("%s:%d", text, icon_size);
+	key = g_strdup_printf ("%s:%u", text, icon_size);
 
 	if (!pixbuf_cache)
 		pixbuf_cache = g_hash_table_new_full (
@@ -391,9 +398,14 @@ bonobo_ui_util_xml_set_image (GtkImage     *image,
 
 		if ((name == NULL) || !g_file_test (name, G_FILE_TEST_EXISTS))
 			g_warning ("Could not find GNOME pixmap file %s", text);
-		else
-			pixbuf = gdk_pixbuf_new_from_file (name, NULL);
-
+		else {
+ 			int w, h;
+			GtkSettings *settings = gtk_widget_get_settings (GTK_WIDGET (image));
+ 			if (gtk_icon_size_lookup_for_settings (settings, icon_size, &w, &h))
+ 				pixbuf = gdk_pixbuf_new_from_file_at_size (name, w, h, NULL);
+ 			else
+ 				pixbuf = gdk_pixbuf_new_from_file (name, NULL);
+ 		}
 		g_free (name);
 
 	} else if (!strcmp (type, "pixbuf"))
@@ -419,6 +431,8 @@ bonobo_ui_util_xml_set_image (GtkImage     *image,
  * This function extracts a pixbuf from the node and returns a GtkWidget
  * containing a display of the pixbuf.
  *
+ * Unused internally.
+ *
  * Return value: the widget.
  **/
 GtkWidget *
@@ -617,6 +631,7 @@ bonobo_ui_util_build_help_menu (BonoboUIComponent *listener,
 	bonobo_ui_node_set_attr (node, "tip", _("View help for this application"));
 	bonobo_ui_node_set_attr (node, "pixtype", "stock");
 	bonobo_ui_node_set_attr (node, "pixname", "gtk-help");
+	bonobo_ui_node_set_attr (node, "accel", "F1");
 
 	cl = g_new0 (HelpDisplayClosure, 1);
 	cl->app_name = g_strdup (app_name);
@@ -649,26 +664,29 @@ bonobo_ui_util_get_ui_fname (const char *component_datadir,
 {
 	char *fname, *name;
 
-	if ((file_name [0] == '/' || file_name [0] == '.') &&
+	if ((g_path_is_absolute (file_name) || file_name [0] == '.') &&
 	    g_file_test (file_name, G_FILE_TEST_EXISTS))
 		return g_strdup (file_name);
 
 	if (component_datadir) {
-		fname = g_strdup_printf ("%s/gnome-2.0/ui/%s",
-					 component_datadir, file_name);
+		fname = g_build_filename (component_datadir,
+					  "gnome-2.0",
+					  "ui",
+					  file_name,
+					  NULL);
 
 		if (g_file_test (fname, G_FILE_TEST_EXISTS))
 			return fname;
 		g_free (fname);
 	}
 
-	name = g_strconcat (BONOBO_UIDIR, file_name, NULL);
+	name = g_build_filename (BONOBO_UIDIR, file_name, NULL);
 	if (g_file_test (name, G_FILE_TEST_EXISTS))
 		return name;
 	g_free (name);
 
 	if (component_datadir) {
-		name = g_strconcat (component_datadir, "/", file_name, NULL);
+		name = g_build_filename (component_datadir, file_name, NULL);
 		if (g_file_test (name, G_FILE_TEST_EXISTS))
 			return name;
 		g_free (name);
@@ -710,7 +728,11 @@ bonobo_ui_util_translate_ui (BonoboUINode *node)
 			a->id = g_quark_from_static_string (str + 1);
 
 			old = a->value;
-			a->value = xmlStrdup (_(a->value));
+#ifdef ENABLE_NLS
+			a->value = xmlStrdup (gettext(a->value));
+#else
+			a->value = xmlStrdup (a->value);
+#endif
 			xmlFree (old);
 		}
 	}
@@ -942,6 +964,8 @@ bonobo_ui_util_set_ui (BonoboUIComponent *component,
 			component, fname, app_datadir, app_name);
 
 		ui = bonobo_ui_node_to_string (node, TRUE);
+		if (!ui)
+			return;
 
 		bonobo_ui_node_free (node);
 		
