@@ -18,7 +18,7 @@
 #include <bonobo/bonobo-ui-toolbar-button-item.h>
 #include <bonobo/bonobo-window.h>
 
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n.h>
 #include <bonobo/bonobo-ui-main.h>
 #include <bonobo/bonobo-ui-preferences.h>
 
@@ -58,7 +58,7 @@ static const char * tame_xpm[] = {
 "                        "
 };
 
-BonoboUIComponent *global_component;
+static BonoboUIComponent *global_component;
 
 #define PRINT_PREF(spref, pref) \
 	fprintf (stderr, "\t" spref " : %s\n", \
@@ -159,7 +159,7 @@ toggled_cb (BonoboUIComponent           *component,
 	    const char                  *state,
 	    gpointer                     user_data)
 {
-	fprintf (stderr, "toggled to '%s' type '%d' path '%s'\n",
+	fprintf (stderr, "toggled to '%s' type '%u' path '%s'\n",
 		 state, type, path);
 }
 
@@ -221,7 +221,7 @@ do_sane_popup (GtkWidget      *widget,
 	return FALSE;
 }
 
-BonoboUIVerb verbs [] = {
+static BonoboUIVerb verbs [] = {
 	BONOBO_UI_VERB ("FileExit", file_exit_cmd),
 	BONOBO_UI_VERB ("FileOpen", file_open_cmd),
 
@@ -238,6 +238,7 @@ main (int argc, char **argv)
 	BonoboUIContainer *container;
 	Bonobo_UIContainer corba_container;
 	CORBA_Environment  real_ev, *ev;
+	GnomeProgram *program;
 	char *txt, *fname;
 	int i;
 
@@ -309,7 +310,7 @@ main (int argc, char **argv)
 
 	free (malloc (8));
 
-	gnome_program_init ("test-ui", VERSION,
+	program = gnome_program_init ("test-ui", VERSION,
 			    LIBBONOBOUI_MODULE,
 			    argc, argv, NULL);
 
@@ -530,8 +531,9 @@ main (int argc, char **argv)
 	CORBA_exception_free (ev);
 
   	{
-  		char *txt = bonobo_ui_component_get (componenta, "/status/main", TRUE, NULL);
  		const char *good = "<item name=\"main\">WhatA6&gt;</item>\n";
+
+  		txt = bonobo_ui_component_get (componenta, "/status/main", TRUE, NULL);
  
  		if (!txt || strcmp (txt, good)) {
  			g_warning ("Broken merging code '%s' should be '%s'", txt, good);
@@ -665,5 +667,7 @@ main (int argc, char **argv)
 
 	CORBA_exception_free (ev);
 
+	g_object_unref (program);
+
 	return bonobo_ui_debug_shutdown ();
 }
